@@ -54,7 +54,7 @@ rsvg_propegate_error (GError ** err,
 {
         if (err) {
                 *err = NULL;
-                g_set_error (err, rsvg_error_quark (), code, reason);
+                g_set_error (err, rsvg_error_quark (), code, "%s", reason);
         }
 }
 
@@ -234,13 +234,17 @@ fill_info (GdkPixbufFormat *info)
                 "image/svg-xml",
                 "image/vnd.adobe.svg+xml",
                 "text/xml-svg",
+#ifdef HAVE_SVGZ
                 "image/svg+xml-compressed",
+#endif
                 NULL
         };
         static gchar *extensions[] = {
                 "svg",
+#ifdef HAVE_SVGZ
                 "svgz",
                 "svg.gz",
+#endif
                 NULL
         };
 
@@ -254,4 +258,5 @@ fill_info (GdkPixbufFormat *info)
         info->mime_types  = mime_types;
         info->extensions  = extensions;
         info->flags       = GDK_PIXBUF_FORMAT_SCALABLE;
+        info->license     = "LGPL";
 }
