@@ -192,7 +192,7 @@ draw_gap_image(GtkStyle       *style,
   if (image)
     {
       gint thickness;
-      GdkRectangle r1, r2, r3;
+      GdkRectangle r1 = {0,0,0,0}, r2 = {0,0,0,0}, r3 = {0,0,0,0};
       GdkPixbuf *pixbuf = NULL;
       guint components = COMPONENT_ALL;
 
@@ -200,7 +200,7 @@ draw_gap_image(GtkStyle       *style,
 	components |= COMPONENT_CENTER;
 
       if (image->gap_start)
-	pixbuf = theme_pixbuf_get_pixbuf (image->gap_start);
+	pixbuf = theme_pixbuf_get_pixbuf (image->gap_start, -1, -1);
 
       switch (gap_side)
 	{
@@ -984,7 +984,7 @@ GType rsvg_type_style = 0;
 void
 rsvg_style_register_type (GTypeModule *module)
 {
-  static const GTypeInfo object_info =
+  const GTypeInfo object_info =
   {
     sizeof (RsvgStyleClass),
     (GBaseInitFunc) NULL,
