@@ -65,6 +65,7 @@ rsvg_cairo_render_new (cairo_t * cr, double width, double height)
     cairo_render->height = height;
     cairo_render->offset_x = 0;
     cairo_render->offset_y = 0;
+    cairo_render->initial_cr = cr;
     cairo_render->cr = cr;
     cairo_render->cr_stack = NULL;
     cairo_render->bb_stack = NULL;
@@ -142,9 +143,6 @@ rsvg_cairo_new_drawing_ctx (cairo_t * cr, RsvgHandle * handle)
 
     draw->state = NULL;
 
-    /* should this be G_ALLOC_ONLY? */
-    draw->state_allocator = g_mem_chunk_create (RsvgState, 256, G_ALLOC_AND_FREE);
-
     draw->defs = handle->priv->defs;
     draw->base_uri = g_strdup (handle->priv->base_uri);
     draw->dpi_x = handle->priv->dpi_x;
@@ -176,8 +174,8 @@ rsvg_cairo_new_drawing_ctx (cairo_t * cr, RsvgHandle * handle)
     _rsvg_affine_multiply (state->affine, affine, state->affine);
 
     /* adjust transform so that the corner of the bounding box above is
-     * at (0,0) - we compensate for this in rsvg_handle_render_cairo_sub()
-     * below */
+     * at (0,0) - we compensate for this in _set_rsvg_affine() in
+     * rsvg-cairo-render.c and a few other places */
     state->affine[4] -= render->offset_x;
     state->affine[5] -= render->offset_y;
 
@@ -198,27 +196,29 @@ rsvg_cairo_new_drawing_ctx (cairo_t * cr, RsvgHandle * handle)
  *
  * Since: 2.14
  */
-void
+gboolean
 rsvg_handle_render_cairo_sub (RsvgHandle * handle, cairo_t * cr, const char *id)
 {
     RsvgDrawingCtx *draw;
     RsvgNode *drawsub = NULL;
-    RsvgCairoRender *render;
-    cairo_surface_t *surface = cairo_get_target (cr);
-    double save_dx, save_dy;
 
-    g_return_if_fail (handle != NULL);
+    g_return_val_if_fail (handle != NULL, FALSE);
 
     if (!handle->priv->finished)
-        return;
-
-    draw = rsvg_cairo_new_drawing_ctx (cr, handle);
-    if (!draw)
-        return;
+        return FALSE;
 
     if (id && *id)
         drawsub = rsvg_defs_lookup (handle->priv->defs, id);
 
+	if (drawsub == NULL && id != NULL) {
+		/* todo: there's no way to signal that @id doesn't exist */
+		return FALSE;
+	}
+
+    draw = rsvg_cairo_new_drawing_ctx (cr, handle);
+    if (!draw)
+        return FALSE;
+
     while (drawsub != NULL) {
         draw->drawsub_stack = g_slist_prepend (draw->drawsub_stack, drawsub);
         drawsub = drawsub->parent;
@@ -226,23 +226,14 @@ rsvg_handle_render_cairo_sub (RsvgHandle * handle, cairo_t * cr, const char *id)
 
     rsvg_state_push (draw);
     cairo_save (cr);
-    cairo_identity_matrix (cr);
-
-    /* adjust the underlying surface's device offset such that the
-     * bounding box from rsvg_cairo_new_drawing_ctx is placed correctly */
-    cairo_surface_get_device_offset (surface, &save_dx, &save_dy);
-    render = (RsvgCairoRender *) draw->render;
-    cairo_surface_set_device_offset (surface,
-                                     save_dx + render->offset_x,
-                                     save_dy + render->offset_y);
 
     rsvg_node_draw ((RsvgNode *) handle->priv->treebase, draw, 0);
 
-    cairo_surface_set_device_offset (surface, save_dx, save_dy);
-
     cairo_restore (cr);
     rsvg_state_pop (draw);
     rsvg_drawing_ctx_free (draw);
+
+	return TRUE;
 }
 
 /**
@@ -254,8 +245,8 @@ rsvg_handle_render_cairo_sub (RsvgHandle * handle, cairo_t * cr, const char *id)
  *
  * Since: 2.14
  */
-void
+gboolean
 rsvg_handle_render_cairo (RsvgHandle * handle, cairo_t * cr)
 {
-    rsvg_handle_render_cairo_sub (handle, cr, NULL);
+    return rsvg_handle_render_cairo_sub (handle, cr, NULL);
 }
