@@ -106,6 +106,7 @@ rsvg_state_init (RsvgState * state)
     state->has_cap = FALSE;
     state->has_join = FALSE;
     state->has_dash = FALSE;
+    state->has_dashoffset = FALSE;
     state->has_visible = FALSE;
     state->has_cond = FALSE;
     state->has_stop_color = FALSE;
@@ -268,6 +269,10 @@ rsvg_state_inherit_run (RsvgState * dst, const RsvgState * src,
             dst->dash.dash[i] = src->dash.dash[i];
     }
 
+    if (function (dst->has_dashoffset, src->has_dashoffset)) {
+        dst->dash.offset = src->dash.offset;
+    }
+
     if (inherituninheritables) {
         dst->clip_path_ref = src->clip_path_ref;
         dst->mask = src->mask;
@@ -664,7 +669,7 @@ rsvg_parse_style_arg (RsvgHandle * ctx, RsvgState * state, const char *str)
         state->has_miter_limit = TRUE;
         state->miter_limit = g_ascii_strtod (str + arg_off, NULL);
     } else if (rsvg_css_param_match (str, "stroke-dashoffset")) {
-        state->has_dash = TRUE;
+        state->has_dashoffset = TRUE;
         state->dash.offset = _rsvg_css_parse_length (str + arg_off);
         if (state->dash.offset.length < 0.)
             state->dash.offset.length = 0.;
@@ -1416,7 +1421,7 @@ rsvg_state_push (RsvgDrawingCtx * ctx)
     RsvgState *baseon;
 
     baseon = (RsvgState *) g_slist_nth_data (ctx->state, 0);
-    data = g_chunk_new (RsvgState, ctx->state_allocator);
+    data = g_slice_new (RsvgState);
 
     if (baseon) {
         int i;
@@ -1438,7 +1443,7 @@ rsvg_state_pop (RsvgDrawingCtx * ctx)
 
     rsvg_state_finalize (dead_state);
     ctx->state = g_slist_delete_link (ctx->state, link);
-    g_mem_chunk_free (ctx->state_allocator, dead_state);
+    g_slice_free (RsvgState, dead_state);
 }
 
 /*
